@@ -57,7 +57,7 @@ const (
 	requestProjectNewAppOutput = `
 You can add applications to this project with the 'new-app' command. For example, try:
 
-    %[1]s new-app django-psql-example
+    %[1]s new-app ruby~https://github.com/sclorg/ruby-ex.git
 
 to build a new example application in Python. Or use kubectl to deploy a simple Kubernetes application:
 
